aboutsummaryrefslogtreecommitdiff
path: root/engines/glk/alan2/decode.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/glk/alan2/decode.cpp')
-rw-r--r--engines/glk/alan2/decode.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/glk/alan2/decode.cpp b/engines/glk/alan2/decode.cpp
index 2955c37745..4f89380272 100644
--- a/engines/glk/alan2/decode.cpp
+++ b/engines/glk/alan2/decode.cpp
@@ -30,14 +30,14 @@ namespace Alan2 {
/* Bit output */
static int decodeBuffer; /* Bits to be input */
static int bitsToGo; /* Bits still in buffer */
-static int garbageBits; /* Bits past EOF */
+static int garbageBits; /* Bits past EOD */
static int inputBit() {
int bit;
if (!bitsToGo) { /* More bits available ? */
decodeBuffer = txtfil->readByte(); /* No, so get more */
- if (decodeBuffer == EOF) {
+ if (decodeBuffer == EOD) {
garbageBits++;
if (garbageBits > VALUEBITS - 2)
syserr("Error in encoded data file.");